package org.apache.turbine.om;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * This mocks a {@link RetrieverFactory}.
 *
 * @author <a href="mailto:tv@apache.org">Thomas Vandahl</a>
 * @deprecated Retriever and RetrieverFactory are deprecated
 */
@Deprecated
public class MockRetrieverFactory implements RetrieverFactory
{

    /**
     * @see org.apache.turbine.om.RetrieverFactory#getInstance(java.lang.String)
     */
    @Override
    public Retriever getInstance(String className) throws Exception
    {
        return key -> new String(key);
    }

}
